==> Email-ExactTarget-1.6.1.tar.gz: Email-ExactTarget-1.6.1/README.md <==
Email-ExactTarget
=================

[![Build Status](https://travis-ci.org/guillaumeaubert/Email-ExactTarget.png?branch=master)](https://travis-ci.org/guillaumeaubert/Email-ExactTarget)

This module allows you to interact with Exact Target, an Email Service
Provider. It encapsulates all the communications with the API provided by Exact
Target to offer a Perl interface for managing lists and subscribers amongst
other features.

Please note that you will need to register with Exact Target first in order to
obtain an API key and password, as well as agree with the Terms and Conditions
for using the API.


INSTALLATION
------------

To install this module, run the following commands:

	perl Build.PL
	./Build
	./Build test
	./Build install


SUPPORT AND DOCUMENTATION
-------------------------

After installing, you can find documentation for this module with the
perldoc command.

	perldoc Email::ExactTarget


You can also look for information at:

 * [GitHub's request tracker (report bugs here)]
   (https://github.com/guillaumeaubert/Email-ExactTarget/issues)

 * [AnnoCPAN, Annotated CPAN documentation]
   (http://annocpan.org/dist/Email-ExactTarget)

 * [CPAN Ratings]
   (http://cpanratings.perl.org/d/Email-ExactTarget)

 * [MetaCPAN]
   (https://metacpan.org/release/Email-ExactTarget)


LICENSE AND COPYRIGHT
---------------------

Copyright (C) 2009-2013 Guillaume Aubert

This program is free software: you can redistribute it and/or modify it under
the terms of the GNU General Public License version 3 as published by the Free
Software Foundation.

This program is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with
this program. If not, see http://www.gnu.org/licenses/

==> Email-ExactTarget-v1.6.2.tar.gz: Email-ExactTarget-v1.6.2/README.md <==
Email-ExactTarget
=================

[![Build Status](https://travis-ci.org/guillaumeaubert/Email-ExactTarget.png?branch=master)](https://travis-ci.org/guillaumeaubert/Email-ExactTarget)
[![Coverage Status](https://coveralls.io/repos/guillaumeaubert/Email-ExactTarget/badge.png?branch=master)](https://coveralls.io/r/guillaumeaubert/Email-ExactTarget?branch=master)

This module allows you to interact with Exact Target, an Email Service
Provider. It encapsulates all the communications with the API provided by Exact
Target to offer a Perl interface for managing lists and subscribers amongst
other features.

Please note that you will need to register with Exact Target first in order to
obtain an API key and password, as well as agree with the Terms and Conditions
for using the API.


INSTALLATION
------------

To install this module, run the following commands:

	perl Build.PL
	./Build
	./Build test
	./Build install


SUPPORT AND DOCUMENTATION
-------------------------

After installing, you can find documentation for this module with the
perldoc command.

	perldoc Email::ExactTarget


You can also look for information at:

 * [GitHub's request tracker (report bugs here)]
   (https://github.com/guillaumeaubert/Email-ExactTarget/issues)

 * [AnnoCPAN, Annotated CPAN documentation]
   (http://annocpan.org/dist/Email-ExactTarget)

 * [CPAN Ratings]
   (http://cpanratings.perl.org/d/Email-ExactTarget)

 * [MetaCPAN]
   (https://metacpan.org/release/Email-ExactTarget)


LICENSE AND COPYRIGHT
---------------------

Copyright (C) 2009-2014 Guillaume Aubert

This program is free software: you can redistribute it and/or modify it under
the terms of the GNU General Public License version 3 as published by the Free
Software Foundation.

This program is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with
this program. If not, see http://www.gnu.org/licenses/
